package ConfigParse;
use strict;

# Swat 2.1 
# Last updated on 12/10/97
# Copyright (c) by Chris Kight 1997
#
# Parses plain ASCII newline delimited text configuration files
# Takes 2 types of key => value pairs.
# key => scalar
# key => [array]
#
# OOP interface takes the file name as its only argument
#
# Example:
#
# use ConfigParse;
# my $configparse = ConfigParse->new("configfile"); 
# my $gdir = $configparse->get("Global");
# 
# Pass get() the name of the Directive between the : :
# Thus to get the Directive :Global: get("Global");
#
# Where gdir is a reference to a hash containing the key => value
# pairs parsed from the config file.
# If the value is a list of values between [] in the config file,
# then the value is a reference to an array
# Lists are between [] and delimited by ','
# [one,two,three]

sub new {
   my $proto = shift;
   my $class = ref($proto) || $proto;
   my $self = { 
      file       => shift,
      files      => [],
   };
   bless ($self, $class);
   $self->start();
   return $self;
}

my $directive ='';

sub start {
   my $self = shift;
   unless(open(CONFIG,$self->{file})) { die "Could not open config file $self->{file}\n"; }
   while (<CONFIG>) {
       # If any line contains spaces and then a :Directive: set it as our
       # current directive, and proceed
       if ($_ =~ /\s*\:(.*?)\:/) {
	   $directive = $1;
	   next;
       }
       $self->parse_line($_);
   }
}

sub parse_line {
   my $self = shift;

   my $line = shift;
   $line =~ s/\s*\#.*//; # Strip comments with a # comment

   if ($line =~ m/^\s*([^\s]*)\s+\[(.*)\]/) {
       @{$self->{$directive}{$1}} = split(/,/,$2);
       for (@{$self->{$directive}{$1}}) {
	   $_ =~ s/\s*([^ ]+)\s*/$1/;
       }
   } 
   elsif ($line =~ m/^\s*([^\s]+)\s*([^\s]*)/) {
       $self->{$directive}{$1} = $2;
   }
}

sub get {
    my $self = shift;
    my $dir = shift;
    return $self->{$dir};
}
1;
