package text::html;

require HTML::Parser;
use Base;
@ISA = qw(HTML::Parser Base);

use strict;
use Entities();

my ($name,$hash,$array);

sub new {
   my $proto = shift;
   my $class = ref($proto) || $proto;
   my $self = {
      g		=> shift,
      indexing	=> shift,
      indexer   => shift,
      file	=> shift,
      filetype  => shift,
      conts	=> '',
      title 	=> '',
      desc	=> '',
      key	=> '',
      body	=> '',
   };
   bless ($self, $class);
   $self->decide;
   return $self;
}

sub start {		# HTML::Parser runs start() with @_ being [ tagname, [array], {hash} ]
    my $self = shift;
    for (@_) { 
	$name = shift;
	$hash = shift;
	$array = shift;
	foreach my $cat (keys %{$hash}) { 
	    if ($name eq "meta") {
		if ($hash->{"name"} eq $self->{indexing}{metadesc}) {	      
		    $self->{desc} = $hash->{value};
		}
		elsif ($hash->{"name"} eq $self->{indexing}{metakey}) {
		    $self->{key} = $hash->{value};
		}
	    }
	}
    }
}

sub text {
    my $self = shift;
    my $text = shift;
    if ($name eq "title") {
	$self->{title} = $text unless($self->{title});
    } else {
	$self->{body} .= $text;
    }
}

sub initialize {        
    my $self = shift;   
    my $contsref = shift;
    $self->parse($self->{conts}); # Call HTML::Parser::parse() which in return calls start()
}

sub _length {
    my $self   = shift;
    my $text   = shift;
    my $length = shift;
    $text =~ /(([^ ]*\s+){1,$length})/;
    $text = $1;
    return $text;
}

sub get_body {
    my $self = shift;
    $self->{body} = $self->_length($self->{body},$self->{indexing}{bodylength});
    $self->{body} = Entities::decode($self->{body});
    return \$self->{body};
}

sub get_desc {
    my $self = shift;
    unless ($self->{desc}) {
	$self->{desc} = $self->_length($self->{body},$self->{indexing}{desclength});
    }
    $self->{desc} = Entities::decode($self->{desc});
    return \$self->{desc};
}

sub get_key {
    my $self = shift;
    unless ($self->{key}) {
	$self->{key} = $self->_length($self->{body},$self->{indexing}{keylength});
    }
    $self->{key} = Entities::decode($self->{desc});
    return \$self->{key};
}
1;
